@@ -71,17 +71,33 @@ class R3sponse(object):
 	# parameter functions.
 	def get_request_parameter(self, request, identifier):
 		response = self.default_response()
+		format = None
+		if ":" in identifier:
+			identifier,format = identifier.split(":")
+			while True:
+				if " " in format: format = format.replace(" ","")
+				else: break
 		if request.method in ["post", "POST"]:
 			variable = request.POST.get(identifier)
 		else:
 			variable = request.GET.get(identifier)
 		if variable in ["", None]:
 			return variable, self.error_response(f"Define parameter: [{identifier}].")
+		elif format != None:
+			if format in ["str", "string"]: variable = str(variable)
+			elif format in ["int", "integer"]: variable = int(variable)
+			elif format in ["bool", "boolean"]: 
+				if variable in ["true", "True", "TRUE", True]: variable = True
+				else: variable = False
+			elif format in ["float", "double"]: variable = float(variable)
+			elif format in ["array", "list"]: variable = variable.split(",")
+			else:
+				raise ValueError(f"Unrecognized <r3sponse.get_request_parameter> format: {format}.")
 		return variable, self.success_response(f"Succesfully retrieved request parameter [{identifier}].")
 	def get_request_parameters(self, request, identifiers=[], optional=False, empty_value=None):
 		if isinstance(identifiers, str):
 			return self.error_response("__get_request_params__ is used to retrieve several identifiers (array format not string).")
-		params = {}
+		params = ResponseObject()
 		for param in identifiers:
 			param_value, response = self.get_request_parameter(request, param)
 			if response["error"] != None: 
@@ -102,7 +118,16 @@ class R3sponse(object):
 		response = self.default_response()
 		if parameter == empty_value: 
 			return self.error_response(f"Define parameter [{name}].")
-		else: return self.success_response(f"Succesfully checked parameter [{name}].")
+		if ":" in name:
+			name,formats = name.split(":")
+			while True:
+				if " " in formats: formats = formats.replace(" ","")
+				else: break
+			formats = formats.split(",")
+			param_format = Formats.get(parameter, serialize=False)
+			if param_format not in formats:
+				return self.error_response(f"Incorrect parameter [{name}] format, correct format(s): {Files.Array(path=False, array=formats).string(joiner=', ')}.")
+		return self.success_response(f"Succesfully checked parameter [{name}].")
 	def check_parameters(self, parameters={"parameter":None}, empty_value=None):
 		response = self.default_response()
 		for id, value in parameters.items():
@@ -231,6 +256,9 @@ class ResponseObject(object):
 			del self[i]
 			#except: a=1
 		return self
+	# count items.
+	def len(self):
+		return len(self.keys())
 	# support item assignment.
 	def __setitem__(self, key, value):
 		setattr(self, key, value)
